@@ -37,7 +37,7 @@ if (.make.epsf) dev.copy2eps(file="h-w-triangle.ps")
 hh <- c(1.65, 1.70, 1.75, 1.80, 1.85, 1.90)
 lines(hh, 22.5 * hh^2)
 if (.make.epsf) dev.copy2eps(file="h-w-line.ps")
-args(plot.default)
+# args(plot.default) # disabled because unimportant and changed btw 4.5 & 4.6
 c("Huey","Dewey","Louie")
 c('Huey','Dewey','Louie')
 c(T,T,F,T)
@@ -378,19 +378,19 @@ sd(daily.intake)
 quantile(daily.intake)
 t.test(daily.intake,mu=7725)
 t.test(daily.intake,mu=7725)
-wilcox.test(daily.intake, mu=7725)
+wilcox.test(daily.intake, mu=7725, exact=FALSE)
 attach(energy)
 energy
 t.test(expend~stature)
 t.test(expend~stature, var.equal=T)
 var.test(expend~stature)
-wilcox.test(expend~stature)
+wilcox.test(expend~stature, exact=FALSE)
 attach(intake)
 intake
 post - pre
 t.test(pre, post, paired=T)
 t.test(pre, post) #WRONG!
-wilcox.test(pre, post, paired=T)
+wilcox.test(pre, post, paired=T, exact=FALSE)
 rm(list=ls())
 while(search()[2] != "package:ISwR") detach()
 attach(thuesen)
